@@ -237,8 +237,7 @@ arma::mat corr_gauss_matrix_armaC(arma::mat x, arma::mat y, arma::vec theta, dou
 
 
 
-// Trying to get C_dC for Gaussian kernel
-//' Correlation Gaussian matrix in C (symmetric)
+//' Derivative of Gaussian kernel covariance matrix in C
 //' @param x Matrix x
 //' @param theta Theta vector
 //' @param C_nonug cov mat without nugget
@@ -248,32 +247,14 @@ arma::mat corr_gauss_matrix_armaC(arma::mat x, arma::mat y, arma::vec theta, dou
 //' @param s2_nug s2 times the nug
 //' @return Correlation matrix
 //' @export
-//' @examples
-//' corr_gauss_matrix_symC(matrix(c(1,0,0,1),2,2),c(1,1))
 // [[Rcpp::export]]
-arma::cube kernel_gauss_dC(arma::mat x, arma::vec theta, arma::mat C_nonug, bool s2_est, bool beta_est, int lenparams_D, double s2_nug) {
+arma::cube kernel_gauss_dC(arma::mat x, arma::vec theta, arma::mat C_nonug,
+                           bool s2_est, bool beta_est, int lenparams_D,
+                           double s2_nug) {
   int nrow = x.n_rows;
   int nsum = x.n_cols;
   arma::cube dC_dparams(lenparams_D, nrow, nrow);
 
-  //arma::mat out(nrow, nrow)
-  /*for (int i = 0; i < nrow - 1; i++) {
-    for (int j = i + 1; j < nrow; j++) {
-
-      double total = 0;
-      for(int k = 0; k < nsum; ++k) {
-        total += theta[k] * pow((x(i,k) - x(j,k)), 2);
-      }
-      total = exp(-total);
-
-      out(i, j) = total;
-      out(j, i) = total; // since symmetric
-    }
-  }
-  for (int i = 0; i < nrow; i++) {
-    out(i, i) = 1;
-  }*/
-
   if (s2_est) {
     // dC_dparams(lenparams_D,,) = C * log(10.0);
     for (int i = 0; i < nrow - 1; i++) {
@@ -302,16 +283,3 @@ arma::cube kernel_gauss_dC(arma::mat x, arma::vec theta, arma::mat C_nonug, bool
 
   return dC_dparams;
 }
-
-
-
-
-
-// You can include R code blocks in C++ files processed with sourceCpp
-// (useful for testing and development). The R code will be automatically
-// run after the compilation.
-//
-
-/*** R
-#timesTwo(42)
-*/
